MethodChannelQuickcapture class

An implementation of QuickcapturePlatform that uses method channels.

Inheritance

Constructors

MethodChannelQuickcapture()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateLicense({String? android, String? ios}) → Future<bool?>
override
assetCapture() → Future<String?>
override
buildPDF(List<String> imagePaths) → Future<String>
override
buildPDFForLastCapture() → Future<String?>
override
buildTiff(List<String> imagePaths) → Future<String?>
override
buildTIFFForLastCapture() → Future<String?>
override
compressToJPEG(String imagePath) → Future<String?>
override
detectHumanFaces(String imagePath) → Future<String?>
Detects human faces in the given image.
override
disableScreenProtection() → Future<void>
override
enableScreenProtection() → Future<void>
override
generateBARCode(String data, bool includeText) → Future<String?>
override
generateQRCode(String data) → Future<String?>
override
getCurrentDigiPin() → Future<String?>
override
getDeviceInfo() → Future<String?>
override
getDeviceSecurityInfo() → Future<String?>
override
getLocationInfo() → Future<String?>
override
getPlatformVersion() → Future<String?>
override
humanFaceCapture() → Future<String?>
override
initHumanFaceHelper() → Future<bool>
Initializes the human face helper.
override
initialize({Map<String, dynamic>? config}) → Future<String?>
override
matchHumanFaces({required int firstDocumentID, required int firstDocumentFaceIndex, required int secondDocumentID, required int secondDocumentFaceIndex}) → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readImageInfo(String imagePath) → Future<String>
override
setConfig({Map<String, dynamic>? config}) → Future<bool?>
override
setCustomLayout(int customWidth, int customHeight) → Future<bool?>
override
signatureCapture() → Future<String?>
override
startCapture() → Future<String?>
override
startDeviceMonitoring() → Future<void>
override
startImageAttach(String imagePath) → Future<String?>
override
startOpticalCodeCapture() → Future<String>
override
stopDeviceMonitoring() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited